;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
;+
; NAME: date2string
;
; PURPOSE: create a nice and readable format to print a date
;
; CATEGORY: calendar/string
;
; CALLING SEQUENCE: nice_date = date2string(yyyymmdd)
; 
; INPUTS: yyyymmdd the date in the format 
;         yearyearyearyearmonthmonthdayday
;
; KEYWORD PARAMETERS:those of string fonction to specify the
;                    format of the month (the C format)
;
; OUTPUTS: a string containing the date in a easy readable format
;
; COMMON BLOCKS:none
;
; SIDE EFFECTS:?
;
; RESTRICTIONS:?
;
; EXAMPLE:
;
;    IDL> print, date2string(19900123)
;    Jan 23, 1990
;    IDL> print, date2string(19900123, format = '(C(CMOA))')
;    JAN 23, 1990
;
; MODIFICATION HISTORY:Sebastien Masson (smasson@lodyc.jussieu.fr)
; Creation ???
; update/review June 2005 Sebastien Masson.
;-
;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
FUNCTION date2string, yyyymmdd, _EXTRA = ex
;
   sday = strtrim(long(yyyymmdd) MOD 100, 1)
   smonth = strtrim((long(yyyymmdd)/100) MOD 100, 2)
   syear = strtrim(long(yyyymmdd)/10000, 2)
   res = string(format = '(C(CMoa))', 31*(fix(smonth)-1), _EXTRA = ex) $
         + ' ' + sday + ', ' + syear
   return, res
end
